/**
  *  \file client/dialogs/vcrinfo.cc
  *  \brief VCR Info Dialog
  *
  *  (c) 2001-2013 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "client/dialogs/vcrinfo.h"
#include "client/widgets/vcrinfohead.h"
#include "util/nls.h"
#include "gfx/palette.h"
#include "ui/layout.h"
#include "ui/widgets/button.h"
#include "client/widgets/vcrinfomain.h"
#include "client/widgets/helpwidget.h"
#include "ui/widgets/keytranslator.h"
#include "game/classicvcr.h"

namespace {
    class WVcrInfo : public UIWindow {
        ObjectHolder h;
        WVcrInfoHeader head;
        WVcrInfoMain* main;
        void init();
        void onMove();
     public:
        WVcrInfo(GClassicVcrDatabase& db, int slot, int side);
        bool handleEvent(const UIEvent& event, bool second_pass);
    };
}

WVcrInfo::WVcrInfo(GClassicVcrDatabase& db, int slot, int side)
    : UIWindow(_("Combat Information"), BLUE_WINDOW, COLOR_GRAY),
      head(db.getBattle(slot), side)
{
    init();
}

void
WVcrInfo::init()
{
    // VBox
    //   WVcrInfoHeader
    //   WVcrInfoBody
    //   HBox
    //     "Go to"
    //     "Back"
    //     "Tab"
    //     "Ins"
    //     "H"
    setLayout(UIVBoxLayout::instance5);

    main = &h.add(new WVcrInfoMain(false));
    add(head);
    add(*main);

    UIGroup& g = h.add(new UIGroup(UIHBoxLayout::instance5));
    g.add(h.add(new UIButton(0, _("Close"), SDLK_ESCAPE)).addStop());
    g.add(h.add(new UIButton(_("Tab - Other side"), SDLK_TAB)));
    g.add(h.add(new UIButton(_("Ins - Sim"), SDLK_INSERT)));
    g.add(h.add(new UISpacer()));
    g.add(h.add(new UIButton("H", 'h')));
    add(g);
    add(h.add(new UIKeyTranslator()).add(SDLK_RETURN, 0, true));
    add(h.add(new WHelpWidget("pcc2:vcrinfo")));

    head.getList().sig_moved.add(this, &WVcrInfo::onMove);
    pack();
}

void
WVcrInfo::onMove()
{
    main->set(head.getList().getVcrEntry(), head.getList().getSide(), head.getList().getCurrentHull());
}

bool
WVcrInfo::handleEvent(const UIEvent& event, bool second_pass)
{
    if (event.type == ev_Key) {
        switch (event.key.code) {
         case SDLK_TAB:
         case SDLK_TAB + ss_Shift:
            /* Swap sides */
            head.getList().setSide(!head.getList().getSide());
            return true;

         case SDLK_INSERT:
            /* Add to sim, after fight */
            main->addToSim(true);
            return true;

         case SDLK_INSERT + ss_Shift:
            /* Add to sim, before fight */
            main->addToSim(false);
            return true;
        }
    }
    return UIWindow::handleEvent(event, second_pass);
}

void
doVcrInfo(GClassicVcrDatabase& db, int slot, int side)
{
    WVcrInfo info(db, slot, side);
    ui_root->centerWidget(info);
    ui_root->runModal(info);
}
