/**
  *  \file int/interror.h
  *  \brief Interpreter: Error messages
  *
  *  (c) 2001-2013 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_INT_INTERROR_H
#define PCC_V2_INT_INTERROR_H

#include "cpluslib/string.h"
#include "game/error.h"

class IntError : public std::exception {
    string_t error;
    string_t trace;
 public:
    IntError(const char* error);
    IntError(string_t error);
    ~IntError() throw();

    const char* what() const throw();
    string_t getTrace() const
        { return trace; }

    void addTrace(string_t line);

    enum ExpectedType {
        tyNone,
        tyInteger,
        tyBool,                 // needed?
        tyNumeric,
        tyBaseType,
        tyString,
        tyIndexable,
        tyIterable,
        tyRecord,
        tyCallable,
        tyProcedure,
        tyKeymap,
        tyBlob,
        tyFile,
        tyArray
    };

    static IntError unknownIdentifier(string_t name);
    static IntError typeError(ExpectedType expectedType = tyNone);
    static IntError internalError(const char* msg);
    static IntError notSerializable();
    static IntError notAssignable();
    static IntError rangeError();
    static IntError invalidMultiline();
    static IntError expectKeyword(const char* kw);
    static IntError expectKeyword(const char* kw1, const char* kw2);
    static IntError expectSymbol(const char* sym);
    static IntError expectSymbol(const char* sym1, const char* sym2);
    static IntError misplacedKeyword(const char* kw);
    static IntError garbageAtEnd(bool expression);
    static IntError expectIdentifier(const char* what);
    static IntError contextError();
};



#endif
